package de.drazil.homegear;

import java.net.InetAddress;
import java.net.URL;

import org.apache.log4j.Logger;
import org.apache.xmlrpc.client.XmlRpcClient;
import org.apache.xmlrpc.client.XmlRpcClientConfigImpl;

public class HomegearRpcServer {
	private static final Logger Log = Logger.getLogger("HomegearRpcServer");
	private static HomegearRpcServer rpcServer = null;
	private XmlRpcClientConfigImpl rpcConfig = null;
	private XmlRpcClient rpcClient = null;

	public final static int KEEP_ALIVE = 0x1;
	public final static int BINARY_MODE = 0x2;
	public final static int NEW_MFORMAT = 0x4;
	public final static int SUBSCRIBE_PEERS = 0x8;
	public final static int JSON_MODE = 0x10;

	static String HOMEGEAR_SERVER_URL = "10.100.200.88:2001";
	static String EVENT_LOGGER_URL = "10.100.200.5:20080/homeautomation/jsonrpc";

	private HomegearRpcServer() throws Exception {

		rpcConfig = new XmlRpcClientConfigImpl();
		rpcConfig.setServerURL(new URL("http://" + HOMEGEAR_SERVER_URL));
		rpcClient = new XmlRpcClient();
		rpcClient.setConfig(rpcConfig);

	}

	public static Object executeMethod(String methodName, Object parameter[]) throws Exception {
		buildInstance();

		return rpcServer.rpcClient.execute(methodName, parameter);
	}

	public static void run() throws Exception {
		buildInstance();
		HomegearRpcServer.init("http://" + EVENT_LOGGER_URL,
				InetAddress.getLocalHost().getHostName() + ":JsonRpcClient", (KEEP_ALIVE + JSON_MODE + NEW_MFORMAT));
	}

	public static void init(String url, String interfaceId, Integer flags) throws Exception {
		executeMethod("init", new Object[] { url, interfaceId, flags });
	}

	private static HomegearRpcServer buildInstance() throws Exception {
		if (rpcServer == null) {
			rpcServer = new HomegearRpcServer();
		}
		return rpcServer;
	}

	public static void main(String args[]) throws Exception {
		HOMEGEAR_SERVER_URL = args[0];
		EVENT_LOGGER_URL = args[1];
		run();
	}
}
